@@ -93,10 +93,10 @@ def modify():
             print(_("MTProto/Shadowsocks protocol not support https!!!"))
             print("")
             return
-        tm = TLSModifier(group.tag, group.index)
-        tls_status = 'open' if group.tls == 'tls' else 'close'
+        xtls = True if group.tls == "xtls" else False
+        tm = TLSModifier(group.tag, group.index, xtls=xtls)
+        tls_status = 'open' if group.tls in ('tls', 'xtls') else 'close'
         print("{}: {}\n".format(_("group tls status"), tls_status))
-        print("")
         print(_("1.open TLS"))
         print(_("2.close TLS"))
         choice = readchar(_("please select: "))
